Method: TD::ClientMethods#send_bot_start_message

Defined in:
lib/tdlib/client_methods.rb

#send_bot_start_message(bot_user_id:, chat_id:, parameter:) ⇒ TD::Types::Message

Invites a bot to a chat (if it is not yet a member) and sends it the /start command; requires can_invite_users

member right.

Bots can’t be invited to a private chat other than the chat with the bot. Bots can’t be invited to channels (although they can be added as admins) and secret chats. Returns the sent message.

Parameters:

  • bot_user_id (Integer)

    Identifier of the bot.

  • chat_id (Integer)

    Identifier of the target chat.

  • parameter (TD::Types::String)

    A hidden parameter sent to the bot for deep linking purposes (core.telegram.org/bots#deep-linking).

Returns:



7197
7198
7199
7200
7201
7202
# File 'lib/tdlib/client_methods.rb', line 7197

def send_bot_start_message(bot_user_id:, chat_id:, parameter:)
  broadcast('@type'       => 'sendBotStartMessage',
            'bot_user_id' => bot_user_id,
            'chat_id'     => chat_id,
            'parameter'   => parameter)
end