Class: TD::Types::AvailableReactions

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/available_reactions.rb

Overview

Represents a list of reactions that can be added to a message.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#allow_custom_emojiBoolean

True, if any custom emoji reaction can be added by Telegram Premium subscribers.

Returns:

  • (Boolean)

    the current value of allow_custom_emoji



11
12
13
# File 'lib/tdlib/types/available_reactions.rb', line 11

def allow_custom_emoji
  @allow_custom_emoji
end

#are_tagsBoolean

True, if the reactions will be tags and the message can be found by them.

Returns:

  • (Boolean)

    the current value of are_tags



11
12
13
# File 'lib/tdlib/types/available_reactions.rb', line 11

def are_tags
  @are_tags
end

List of popular reactions.

Returns:



11
12
13
# File 'lib/tdlib/types/available_reactions.rb', line 11

def popular_reactions
  @popular_reactions
end

#recent_reactionsArray<TD::Types::AvailableReaction>

List of recently used reactions.

Returns:



11
12
13
# File 'lib/tdlib/types/available_reactions.rb', line 11

def recent_reactions
  @recent_reactions
end

#top_reactionsArray<TD::Types::AvailableReaction>

List of reactions to be shown at the top.

Returns:



11
12
13
# File 'lib/tdlib/types/available_reactions.rb', line 11

def top_reactions
  @top_reactions
end

#unavailability_reasonTD::Types::ReactionUnavailabilityReason?

The reason why the current user can't add reactions to the message, despite some other users can; may be null if none.

Returns:



11
12
13
# File 'lib/tdlib/types/available_reactions.rb', line 11

def unavailability_reason
  @unavailability_reason
end