Class: TD::Types::ChatAdministratorRights

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/chat_administrator_rights.rb

Overview

Describes rights of the administrator.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#can_change_info ⇒ Boolean

True, if the administrator can change the chat title, photo, and other settings.

Returns:

  • (Boolean) —

    the current value of can_change_info



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_change_info
  @can_change_info
end

#can_delete_messages ⇒ Boolean

True, if the administrator can delete messages of other users.

Returns:

  • (Boolean) —

    the current value of can_delete_messages



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_delete_messages
  @can_delete_messages
end

#can_delete_stories ⇒ Boolean

True, if the administrator can delete stories posted by other users; applicable to supergroups and channels only.

Returns:

  • (Boolean) —

    the current value of can_delete_stories



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_delete_stories
  @can_delete_stories
end

#can_edit_messages ⇒ Boolean

True, if the administrator can edit messages of other users and pin messages; applicable to channels only.

Returns:

  • (Boolean) —

    the current value of can_edit_messages



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_edit_messages
  @can_edit_messages
end

#can_edit_stories ⇒ Boolean

True, if the administrator can edit stories posted by other users, post stories to the chat page, pin chat stories, and access story archive; applicable to supergroups and channels only.

Returns:

  • (Boolean) —

    the current value of can_edit_stories



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_edit_stories
  @can_edit_stories
end

#can_invite_users ⇒ Boolean

True, if the administrator can invite new users to the chat.

Returns:

  • (Boolean) —

    the current value of can_invite_users



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_invite_users
  @can_invite_users
end

#can_manage_chat ⇒ Boolean

True, if the administrator can access the chat event log, get boost list, see hidden supergroup and channel members, report supergroup spam messages and ignore slow mode. Implied by any other privilege; applicable to supergroups and channels only.

Returns:

  • (Boolean) —

    the current value of can_manage_chat



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_manage_chat
  @can_manage_chat
end

#can_manage_topics ⇒ Boolean

True, if the administrator can create, rename, close, reopen, hide, and unhide forum topics; applicable to forum supergroups only.

Returns:

  • (Boolean) —

    the current value of can_manage_topics



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_manage_topics
  @can_manage_topics
end

#can_manage_video_chats ⇒ Boolean

True, if the administrator can manage video chats.

Returns:

  • (Boolean) —

    the current value of can_manage_video_chats



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_manage_video_chats
  @can_manage_video_chats
end

#can_pin_messages ⇒ Boolean

True, if the administrator can pin messages; applicable to basic groups and supergroups only.

Returns:

  • (Boolean) —

    the current value of can_pin_messages



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_pin_messages
  @can_pin_messages
end

#can_post_messages ⇒ Boolean

True, if the administrator can create channel posts or view channel statistics; applicable to channels only.

Returns:

  • (Boolean) —

    the current value of can_post_messages



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_post_messages
  @can_post_messages
end

#can_post_stories ⇒ Boolean

True, if the administrator can create new chat stories, or edit and delete posted stories; applicable to supergroups and channels only.

Returns:

  • (Boolean) —

    the current value of can_post_stories



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_post_stories
  @can_post_stories
end

#can_promote_members ⇒ Boolean

True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that were directly or indirectly promoted by them.

Returns:

  • (Boolean) —

    the current value of can_promote_members



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_promote_members
  @can_promote_members
end

#can_restrict_members ⇒ Boolean

True, if the administrator can restrict, ban, or unban chat members or view supergroup statistics; always true for channels.

Returns:

  • (Boolean) —

    the current value of can_restrict_members



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def can_restrict_members
  @can_restrict_members
end

#is_anonymous ⇒ Boolean

True, if the administrator isn't shown in the chat member list and sends messages anonymously; applicable to supergroups only.

Returns:

  • (Boolean) —

    the current value of is_anonymous



31
32
33
# File 'lib/tdlib/types/chat_administrator_rights.rb', line 31

def is_anonymous
  @is_anonymous
end