Class: TD::Types::ChatEventLogFilters

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/chat_event_log_filters.rb

Overview

Represents a set of filters used to obtain a chat event log.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#forum_changesBoolean

True, if forum-related actions need to be returned.

Returns:

  • (Boolean)

    the current value of forum_changes



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def forum_changes
  @forum_changes
end

#info_changesBoolean

True, if changes in chat information need to be returned.

Returns:

  • (Boolean)

    the current value of info_changes



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def info_changes
  @info_changes
end

True, if changes to invite links need to be returned.

Returns:

  • (Boolean)

    the current value of invite_link_changes



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def invite_link_changes
  @invite_link_changes
end

#member_invitesBoolean

True, if invited member events need to be returned.

Returns:

  • (Boolean)

    the current value of member_invites



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def member_invites
  @member_invites
end

#member_joinsBoolean

True, if members joining events need to be returned.

Returns:

  • (Boolean)

    the current value of member_joins



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def member_joins
  @member_joins
end

#member_leavesBoolean

True, if members leaving events need to be returned.

Returns:

  • (Boolean)

    the current value of member_leaves



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def member_leaves
  @member_leaves
end

#member_promotionsBoolean

True, if member promotion/demotion events need to be returned.

Returns:

  • (Boolean)

    the current value of member_promotions



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def member_promotions
  @member_promotions
end

#member_restrictionsBoolean

True, if member restricted/unrestricted/banned/unbanned events need to be returned.

Returns:

  • (Boolean)

    the current value of member_restrictions



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def member_restrictions
  @member_restrictions
end

#message_deletionsBoolean

True, if message deletions need to be returned.

Returns:

  • (Boolean)

    the current value of message_deletions



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def message_deletions
  @message_deletions
end

#message_editsBoolean

True, if message edits need to be returned.

Returns:

  • (Boolean)

    the current value of message_edits



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def message_edits
  @message_edits
end

#message_pinsBoolean

True, if pin/unpin events need to be returned.

Returns:

  • (Boolean)

    the current value of message_pins



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def message_pins
  @message_pins
end

#setting_changesBoolean

True, if changes in chat settings need to be returned.

Returns:

  • (Boolean)

    the current value of setting_changes



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def setting_changes
  @setting_changes
end

#video_chat_changesBoolean

True, if video chat actions need to be returned.

Returns:

  • (Boolean)

    the current value of video_chat_changes



18
19
20
# File 'lib/tdlib/types/chat_event_log_filters.rb', line 18

def video_chat_changes
  @video_chat_changes
end