Class: TD::Types::ChatNotificationSettings

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/chat_notification_settings.rb

Overview

Contains information about notification settings for a chat or a forum topic.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#disable_mention_notifications ⇒ Boolean

If true, notifications for messages with mentions will be created as for an ordinary unread message.

Returns:

  • (Boolean) —

    the current value of disable_mention_notifications



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def disable_mention_notifications
  @disable_mention_notifications
end

#disable_pinned_message_notifications ⇒ Boolean

If true, notifications for incoming pinned messages will be created as for an ordinary unread message.

Returns:

  • (Boolean) —

    the current value of disable_pinned_message_notifications



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def disable_pinned_message_notifications
  @disable_pinned_message_notifications
end

#mute_for ⇒ Integer

Time left before notifications will be unmuted, in seconds.

Returns:

  • (Integer) —

    the current value of mute_for



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def mute_for
  @mute_for
end

#mute_stories ⇒ Boolean

True, if story notifications are disabled for the chat.

Returns:

  • (Boolean) —

    the current value of mute_stories



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def mute_stories
  @mute_stories
end

#show_preview ⇒ Boolean

True, if message content must be displayed in notifications.

Returns:

  • (Boolean) —

    the current value of show_preview



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def show_preview
  @show_preview
end

#show_story_sender ⇒ Boolean

True, if the sender of stories must be displayed in notifications.

Returns:

  • (Boolean) —

    the current value of show_story_sender



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def show_story_sender
  @show_story_sender
end

#sound_id ⇒ Integer

Identifier of the notification sound to be played for messages; 0 if sound is disabled.

Returns:

  • (Integer) —

    the current value of sound_id



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def sound_id
  @sound_id
end

#story_sound_id ⇒ Integer

Identifier of the notification sound to be played for stories; 0 if sound is disabled.

Returns:

  • (Integer) —

    the current value of story_sound_id



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def story_sound_id
  @story_sound_id
end

#use_default_disable_mention_notifications ⇒ Boolean

If true, the value for the relevant type of chat or the forum chat is used instead of disable_mention_notifications.

Returns:

  • (Boolean) —

    the current value of use_default_disable_mention_notifications



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def use_default_disable_mention_notifications
  @use_default_disable_mention_notifications
end

#use_default_disable_pinned_message_notifications ⇒ Boolean

If true, the value for the relevant type of chat or the forum chat is used instead of disable_pinned_message_notifications.

Returns:

  • (Boolean) —

    the current value of use_default_disable_pinned_message_notifications



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def use_default_disable_pinned_message_notifications
  @use_default_disable_pinned_message_notifications
end

#use_default_mute_for ⇒ Boolean

If true, the value for the relevant type of chat or the forum chat is used instead of mute_for.

Returns:

  • (Boolean) —

    the current value of use_default_mute_for



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def use_default_mute_for
  @use_default_mute_for
end

#use_default_mute_stories ⇒ Boolean

If true, the value for the relevant type of chat is used instead of mute_stories.

Returns:

  • (Boolean) —

    the current value of use_default_mute_stories



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def use_default_mute_stories
  @use_default_mute_stories
end

#use_default_show_preview ⇒ Boolean

If true, the value for the relevant type of chat or the forum chat is used instead of show_preview.

Returns:

  • (Boolean) —

    the current value of use_default_show_preview



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def use_default_show_preview
  @use_default_show_preview
end

#use_default_show_story_sender ⇒ Boolean

If true, the value for the relevant type of chat is used instead of show_story_sender.

Returns:

  • (Boolean) —

    the current value of use_default_show_story_sender



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def use_default_show_story_sender
  @use_default_show_story_sender
end

#use_default_sound ⇒ Boolean

If true, the value for the relevant type of chat or the forum chat is used instead of sound_id.

Returns:

  • (Boolean) —

    the current value of use_default_sound



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def use_default_sound
  @use_default_sound
end

#use_default_story_sound ⇒ Boolean

If true, the value for the relevant type of chat is used instead of story_sound_id.

Returns:

  • (Boolean) —

    the current value of use_default_story_sound



31
32
33
# File 'lib/tdlib/types/chat_notification_settings.rb', line 31

def use_default_story_sound
  @use_default_story_sound
end