Class: TD::Types::ChatPermissions

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/chat_permissions.rb

Overview

Describes actions that a user is allowed to take in a chat.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

True, if the user may add a link preview to their messages.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_add_link_previews
  @can_add_link_previews
end

#can_change_infoBoolean

True, if the user can change the chat title, photo, and other settings.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_change_info
  @can_change_info
end

#can_create_topicsBoolean

True, if the user can create topics.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_create_topics
  @can_create_topics
end

#can_invite_usersBoolean

True, if the user can invite new users to the chat.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_invite_users
  @can_invite_users
end

#can_pin_messagesBoolean

True, if the user can pin messages.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_pin_messages
  @can_pin_messages
end

#can_send_audiosBoolean

True, if the user can send music files.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_send_audios
  @can_send_audios
end

#can_send_basic_messagesBoolean

True, if the user can send text messages, contacts, giveaways, giveaway winners, invoices, locations, and venues.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_send_basic_messages
  @can_send_basic_messages
end

#can_send_documentsBoolean

True, if the user can send documents.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_send_documents
  @can_send_documents
end

#can_send_other_messagesBoolean

True, if the user can send animations, games, stickers, and dice and use inline bots.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_send_other_messages
  @can_send_other_messages
end

#can_send_photosBoolean

True, if the user can send photos.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_send_photos
  @can_send_photos
end

#can_send_pollsBoolean

True, if the user can send polls.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_send_polls
  @can_send_polls
end

#can_send_video_notesBoolean

True, if the user can send video notes.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_send_video_notes
  @can_send_video_notes
end

#can_send_videosBoolean

True, if the user can send videos.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_send_videos
  @can_send_videos
end

#can_send_voice_notesBoolean

True, if the user can send voice notes.



20
21
22
# File 'lib/tdlib/types/chat_permissions.rb', line 20

def can_send_voice_notes
  @can_send_voice_notes
end