Class: TD::Types::InputStoryContent::Video

Inherits:
TD::Types::InputStoryContent show all
Defined in:
lib/tdlib/types/input_story_content/video.rb

Overview

A video story.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#added_sticker_file_idsArray<Integer>

File identifiers of the stickers added to the video, if applicable.

Returns:

  • (Array<Integer>)

    the current value of added_sticker_file_ids



12
13
14
# File 'lib/tdlib/types/input_story_content/video.rb', line 12

def added_sticker_file_ids
  @added_sticker_file_ids
end

#cover_frame_timestampFloat

Timestamp of the frame, which will be used as video thumbnail.

Returns:

  • (Float)

    the current value of cover_frame_timestamp



12
13
14
# File 'lib/tdlib/types/input_story_content/video.rb', line 12

def cover_frame_timestamp
  @cover_frame_timestamp
end

#durationFloat

Precise duration of the video, in seconds; 0-60.

Returns:

  • (Float)

    the current value of duration



12
13
14
# File 'lib/tdlib/types/input_story_content/video.rb', line 12

def duration
  @duration
end

#is_animationBoolean

True, if the video has no sound.

Returns:

  • (Boolean)

    the current value of is_animation



12
13
14
# File 'lib/tdlib/types/input_story_content/video.rb', line 12

def is_animation
  @is_animation
end

#videoTD::Types::InputFile

Video to be sent. The video size must be 720x1280. The video must be streamable and stored in MPEG4 format, after encoding with x265 codec and key frames added each second.

Returns:



12
13
14
# File 'lib/tdlib/types/input_story_content/video.rb', line 12

def video
  @video
end