Class: TD::Types::MessageProperties

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/message_properties.rb

Overview

Contains properties of a message and describes actions that can be done with the message right now.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#can_be_deleted_for_all_users ⇒ Boolean

True, if the message can be deleted for all users using the method deleteMessages with revoke == true.

Returns:

  • (Boolean) —

    the current value of can_be_deleted_for_all_users



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_deleted_for_all_users
  @can_be_deleted_for_all_users
end

#can_be_deleted_only_for_self ⇒ Boolean

True, if the message can be deleted only for the current user while other users will continue to see it using the method deleteMessages with revoke == false.

Returns:

  • (Boolean) —

    the current value of can_be_deleted_only_for_self



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_deleted_only_for_self
  @can_be_deleted_only_for_self
end

#can_be_edited ⇒ Boolean

True, if the message can be edited using the methods editMessageText, editMessageMedia, editMessageCaption, or editMessageReplyMarkup. For live location and poll messages this fields shows whether editMessageLiveLocation or stopPoll can be used with this message.

Returns:

  • (Boolean) —

    the current value of can_be_edited



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_edited
  @can_be_edited
end

#can_be_forwarded ⇒ Boolean

True, if the message can be forwarded using InputMessageContent::Forwarded or forwardMessages.

Returns:

  • (Boolean) —

    the current value of can_be_forwarded



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_forwarded
  @can_be_forwarded
end

#can_be_paid ⇒ Boolean

True, if the message can be paid using inputInvoiceMessage.

Returns:

  • (Boolean) —

    the current value of can_be_paid



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_paid
  @can_be_paid
end

#can_be_pinned ⇒ Boolean

True, if the message can be pinned or unpinned in the chat using pinChatMessage or unpinChatMessage.

Returns:

  • (Boolean) —

    the current value of can_be_pinned



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_pinned
  @can_be_pinned
end

#can_be_replied ⇒ Boolean

True, if the message can be replied in the same chat and forum topic using inputMessageReplyToMessage.

Returns:

  • (Boolean) —

    the current value of can_be_replied



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_replied
  @can_be_replied
end

#can_be_replied_in_another_chat ⇒ Boolean

True, if the message can be replied in another chat or forum topic using inputMessageReplyToExternalMessage.

Returns:

  • (Boolean) —

    the current value of can_be_replied_in_another_chat



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_replied_in_another_chat
  @can_be_replied_in_another_chat
end

#can_be_saved ⇒ Boolean

True, if content of the message can be saved locally or copied using InputMessageContent::Forwarded or forwardMessages with copy options.

Returns:

  • (Boolean) —

    the current value of can_be_saved



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_saved
  @can_be_saved
end

#can_be_shared_in_story ⇒ Boolean

True, if the message can be shared in a story using inputStoryAreaTypeMessage.

Returns:

  • (Boolean) —

    the current value of can_be_shared_in_story



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_be_shared_in_story
  @can_be_shared_in_story
end

#can_edit_scheduling_state ⇒ Boolean

True, if scheduling state of the message can be edited.

Returns:

  • (Boolean) —

    the current value of can_edit_scheduling_state



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_edit_scheduling_state
  @can_edit_scheduling_state
end

#can_get_embedding_code ⇒ Boolean

True, if code for message embedding can be received using getMessageEmbeddingCode.

Returns:

  • (Boolean) —

    the current value of can_get_embedding_code



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_get_embedding_code
  @can_get_embedding_code
end

True, if a link can be generated for the message using getMessageLink.

Returns:

  • (Boolean) —

    the current value of can_get_link



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_get_link
  @can_get_link
end

True, if media timestamp links can be generated for media timestamp entities in the message text, caption or link preview description using getMessageLink.

Returns:

  • (Boolean) —

    the current value of can_get_media_timestamp_links



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_get_media_timestamp_links
  @can_get_media_timestamp_links
end

#can_get_message_thread ⇒ Boolean

True, if information about the message thread is available through getMessageThread and getMessageThreadHistory.

Returns:

  • (Boolean) —

    the current value of can_get_message_thread



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_get_message_thread
  @can_get_message_thread
end

#can_get_read_date ⇒ Boolean

True, if read date of the message can be received through getMessageReadDate.

Returns:

  • (Boolean) —

    the current value of can_get_read_date



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_get_read_date
  @can_get_read_date
end

#can_get_statistics ⇒ Boolean

True, if message statistics are available through getMessageStatistics and message forwards can be received using getMessagePublicForwards.

Returns:

  • (Boolean) —

    the current value of can_get_statistics



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_get_statistics
  @can_get_statistics
end

#can_get_viewers ⇒ Boolean

True, if chat members already viewed the message can be received through getMessageViewers.

Returns:

  • (Boolean) —

    the current value of can_get_viewers



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_get_viewers
  @can_get_viewers
end

#can_recognize_speech ⇒ Boolean

True, if speech can be recognized for the message through recognizeSpeech.

Returns:

  • (Boolean) —

    the current value of can_recognize_speech



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_recognize_speech
  @can_recognize_speech
end

#can_report_chat ⇒ Boolean

True, if the message can be reported using reportChat.

Returns:

  • (Boolean) —

    the current value of can_report_chat



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_report_chat
  @can_report_chat
end

#can_report_reactions ⇒ Boolean

True, if reactions on the message can be reported through reportMessageReactions.

Returns:

  • (Boolean) —

    the current value of can_report_reactions



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_report_reactions
  @can_report_reactions
end

#can_report_supergroup_spam ⇒ Boolean

True, if the message can be reported using reportSupergroupSpam.

Returns:

  • (Boolean) —

    the current value of can_report_supergroup_spam



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_report_supergroup_spam
  @can_report_supergroup_spam
end

#can_set_fact_check ⇒ Boolean

True, if fact check for the message can be changed through setMessageFactCheck.

Returns:

  • (Boolean) —

    the current value of can_set_fact_check



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def can_set_fact_check
  @can_set_fact_check
end

#need_show_statistics ⇒ Boolean

True, if message statistics must be available from context menu of the message.

Returns:

  • (Boolean) —

    the current value of need_show_statistics



46
47
48
# File 'lib/tdlib/types/message_properties.rb', line 46

def need_show_statistics
  @need_show_statistics
end