Class: TD::Types::MessageReactions

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/message_reactions.rb

Overview

Contains a list of reactions added to a message.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#are_tagsBoolean

True, if the reactions are tags and Telegram Premium users can filter messages by them.

Returns:

  • (Boolean)

    the current value of are_tags



9
10
11
# File 'lib/tdlib/types/message_reactions.rb', line 9

def are_tags
  @are_tags
end

#can_get_added_reactionsBoolean

True, if the list of added reactions is available using getMessageAddedReactions.

Returns:

  • (Boolean)

    the current value of can_get_added_reactions



9
10
11
# File 'lib/tdlib/types/message_reactions.rb', line 9

def can_get_added_reactions
  @can_get_added_reactions
end

Information about top users that added the paid reaction.

Returns:



9
10
11
# File 'lib/tdlib/types/message_reactions.rb', line 9

def paid_reactors
  @paid_reactors
end

#reactionsArray<TD::Types::MessageReaction>

List of added reactions.

Returns:



9
10
11
# File 'lib/tdlib/types/message_reactions.rb', line 9

def reactions
  @reactions
end