Class: TD::Types::MessageReadDate::MyPrivacyRestricted

Inherits:
TD::Types::MessageReadDate show all
Defined in:
lib/tdlib/types/message_read_date/my_privacy_restricted.rb

Overview

The read date is unknown due to privacy settings of the current user, but will be known if the user subscribes to Telegram Premium.

Method Summary

Methods inherited from Base

#to_hash, #to_json