Class: TD::Types::PremiumStatePaymentOption

Inherits:
Base
  • Object
show all
Defined in:
lib/tdlib/types/premium_state_payment_option.rb

Overview

Describes an option for buying or upgrading Telegram Premium for self.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#is_currentBoolean

True, if this is the currently used Telegram Premium subscription option.



10
11
12
# File 'lib/tdlib/types/premium_state_payment_option.rb', line 10

def is_current
  @is_current
end

#is_upgradeBoolean

True, if the payment option can be used to upgrade the existing Telegram Premium subscription.



10
11
12
# File 'lib/tdlib/types/premium_state_payment_option.rb', line 10

def is_upgrade
  @is_upgrade
end

#last_transaction_idTD::Types::String

Identifier of the last in-store transaction for the currently used option.



10
11
12
# File 'lib/tdlib/types/premium_state_payment_option.rb', line 10

def last_transaction_id
  @last_transaction_id
end

#payment_optionTD::Types::PremiumPaymentOption

Information about the payment option.



10
11
12
# File 'lib/tdlib/types/premium_state_payment_option.rb', line 10

def payment_option
  @payment_option
end