Class: TD::Types::TelegramPaymentPurpose::GiftedStars

Inherits:
TD::Types::TelegramPaymentPurpose show all
Defined in:
lib/tdlib/types/telegram_payment_purpose/gifted_stars.rb

Overview

The user buying Telegram Stars for other users.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#amountInteger

Paid amount, in the smallest units of the currency.



8
9
10
# File 'lib/tdlib/types/telegram_payment_purpose/gifted_stars.rb', line 8

def amount
  @amount
end

#currencyTD::Types::String

ISO 4217 currency code of the payment currency.



8
9
10
# File 'lib/tdlib/types/telegram_payment_purpose/gifted_stars.rb', line 8

def currency
  @currency
end

#star_countInteger

Number of bought Telegram Stars.



8
9
10
# File 'lib/tdlib/types/telegram_payment_purpose/gifted_stars.rb', line 8

def star_count
  @star_count
end

#user_idInteger

Identifier of the user to which Telegram Stars are gifted.



8
9
10
# File 'lib/tdlib/types/telegram_payment_purpose/gifted_stars.rb', line 8

def user_id
  @user_id
end