Class: TD::Types::TelegramPaymentPurpose::PremiumGiftCodes

Inherits:
TD::Types::TelegramPaymentPurpose show all
Defined in:
lib/tdlib/types/telegram_payment_purpose/premium_gift_codes.rb

Overview

The user creating Telegram Premium gift codes for other users.

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#to_hash, #to_json

Instance Attribute Details

#amountInteger

Paid amount, in the smallest units of the currency.



10
11
12
# File 'lib/tdlib/types/telegram_payment_purpose/premium_gift_codes.rb', line 10

def amount
  @amount
end

#boosted_chat_idInteger

Identifier of the supergroup or channel chat, which will be automatically boosted by the users for duration of the Premium subscription and which is administered by the user; 0 if none.



10
11
12
# File 'lib/tdlib/types/telegram_payment_purpose/premium_gift_codes.rb', line 10

def boosted_chat_id
  @boosted_chat_id
end

#currencyTD::Types::String

ISO 4217 currency code of the payment currency.



10
11
12
# File 'lib/tdlib/types/telegram_payment_purpose/premium_gift_codes.rb', line 10

def currency
  @currency
end

#month_countInteger

Number of months the Telegram Premium subscription will be active for the users.



10
11
12
# File 'lib/tdlib/types/telegram_payment_purpose/premium_gift_codes.rb', line 10

def month_count
  @month_count
end

#user_idsArray<Integer>

Identifiers of the users which can activate the gift codes.



10
11
12
# File 'lib/tdlib/types/telegram_payment_purpose/premium_gift_codes.rb', line 10

def user_ids
  @user_ids
end