Class: TD::Types::AvailableReactions
- Defined in:
- lib/tdlib/types/available_reactions.rb
Overview
Represents a list of reactions that can be added to a message.
Instance Attribute Summary collapse
-
#allow_custom_emoji ⇒ Boolean
True, if any custom emoji reaction can be added by Telegram Premium subscribers.
-
#are_tags ⇒ Boolean
True, if the reactions will be tags and the message can be found by them.
-
#popular_reactions ⇒ Array<TD::Types::AvailableReaction>
List of popular reactions.
-
#recent_reactions ⇒ Array<TD::Types::AvailableReaction>
List of recently used reactions.
-
#top_reactions ⇒ Array<TD::Types::AvailableReaction>
List of reactions to be shown at the top.
-
#unavailability_reason ⇒ TD::Types::ReactionUnavailabilityReason?
The reason why the current user can't add reactions to the message, despite some other users can; may be null if none.
Method Summary
Methods inherited from Base
Instance Attribute Details
#allow_custom_emoji ⇒ Boolean
True, if any custom emoji reaction can be added by Telegram Premium subscribers.
11 12 13 |
# File 'lib/tdlib/types/available_reactions.rb', line 11 def allow_custom_emoji @allow_custom_emoji end |
#are_tags ⇒ Boolean
True, if the reactions will be tags and the message can be found by them.
11 12 13 |
# File 'lib/tdlib/types/available_reactions.rb', line 11 def end |
#popular_reactions ⇒ Array<TD::Types::AvailableReaction>
List of popular reactions.
11 12 13 |
# File 'lib/tdlib/types/available_reactions.rb', line 11 def popular_reactions @popular_reactions end |
#recent_reactions ⇒ Array<TD::Types::AvailableReaction>
List of recently used reactions.
11 12 13 |
# File 'lib/tdlib/types/available_reactions.rb', line 11 def recent_reactions @recent_reactions end |
#top_reactions ⇒ Array<TD::Types::AvailableReaction>
List of reactions to be shown at the top.
11 12 13 |
# File 'lib/tdlib/types/available_reactions.rb', line 11 def top_reactions @top_reactions end |
#unavailability_reason ⇒ TD::Types::ReactionUnavailabilityReason?
The reason why the current user can't add reactions to the message, despite some other users can; may be null if none.
11 12 13 |
# File 'lib/tdlib/types/available_reactions.rb', line 11 def unavailability_reason @unavailability_reason end |