Class: TD::Types::InputStoryContent::Video
- Inherits:
-
TD::Types::InputStoryContent
- Object
- Dry::Struct
- Base
- TD::Types::InputStoryContent
- TD::Types::InputStoryContent::Video
- Defined in:
- lib/tdlib/types/input_story_content/video.rb
Overview
A video story.
Instance Attribute Summary collapse
-
#added_sticker_file_ids ⇒ Array<Integer>
File identifiers of the stickers added to the video, if applicable.
-
#cover_frame_timestamp ⇒ Float
Timestamp of the frame, which will be used as video thumbnail.
-
#duration ⇒ Float
Precise duration of the video, in seconds; 0-60.
-
#is_animation ⇒ Boolean
True, if the video has no sound.
-
#video ⇒ TD::Types::InputFile
Video to be sent.
Method Summary
Methods inherited from Base
Instance Attribute Details
#added_sticker_file_ids ⇒ Array<Integer>
File identifiers of the stickers added to the video, if applicable.
12 13 14 |
# File 'lib/tdlib/types/input_story_content/video.rb', line 12 def added_sticker_file_ids @added_sticker_file_ids end |
#cover_frame_timestamp ⇒ Float
Timestamp of the frame, which will be used as video thumbnail.
12 13 14 |
# File 'lib/tdlib/types/input_story_content/video.rb', line 12 def end |
#duration ⇒ Float
Precise duration of the video, in seconds; 0-60.
12 13 14 |
# File 'lib/tdlib/types/input_story_content/video.rb', line 12 def duration @duration end |
#is_animation ⇒ Boolean
True, if the video has no sound.
12 13 14 |
# File 'lib/tdlib/types/input_story_content/video.rb', line 12 def is_animation @is_animation end |
#video ⇒ TD::Types::InputFile
Video to be sent. The video size must be 720x1280. The video must be streamable and stored in MPEG4 format, after encoding with x265 codec and key frames added each second.
12 13 14 |
# File 'lib/tdlib/types/input_story_content/video.rb', line 12 def video @video end |