Class: TD::Types::MessageReactions
- Defined in:
- lib/tdlib/types/message_reactions.rb
Overview
Contains a list of reactions added to a message.
Instance Attribute Summary collapse
-
#are_tags ⇒ Boolean
True, if the reactions are tags and Telegram Premium users can filter messages by them.
-
#can_get_added_reactions ⇒ Boolean
True, if the list of added reactions is available using getMessageAddedReactions.
-
#paid_reactors ⇒ Array<TD::Types::PaidReactor>
Information about top users that added the paid reaction.
-
#reactions ⇒ Array<TD::Types::MessageReaction>
List of added reactions.
Method Summary
Methods inherited from Base
Instance Attribute Details
#are_tags ⇒ Boolean
True, if the reactions are tags and Telegram Premium users can filter messages by them.
9 10 11 |
# File 'lib/tdlib/types/message_reactions.rb', line 9 def @are_tags end |
#can_get_added_reactions ⇒ Boolean
True, if the list of added reactions is available using getMessageAddedReactions.
9 10 11 |
# File 'lib/tdlib/types/message_reactions.rb', line 9 def can_get_added_reactions @can_get_added_reactions end |
#paid_reactors ⇒ Array<TD::Types::PaidReactor>
Information about top users that added the paid reaction.
9 10 11 |
# File 'lib/tdlib/types/message_reactions.rb', line 9 def paid_reactors @paid_reactors end |
#reactions ⇒ Array<TD::Types::MessageReaction>
List of added reactions.
9 10 11 |
# File 'lib/tdlib/types/message_reactions.rb', line 9 def reactions @reactions end |