Class: TD::Types::TargetChat::Chosen
- Inherits:
-
TD::Types::TargetChat
- Object
- Dry::Struct
- Base
- TD::Types::TargetChat
- TD::Types::TargetChat::Chosen
- Defined in:
- lib/tdlib/types/target_chat/chosen.rb
Overview
The chat needs to be chosen by the user among chats of the specified types.
Instance Attribute Summary collapse
-
#allow_bot_chats ⇒ Boolean
True, if private chats with other bots are allowed.
-
#allow_channel_chats ⇒ Boolean
True, if channel chats are allowed.
-
#allow_group_chats ⇒ Boolean
True, if basic group and supergroup chats are allowed.
-
#allow_user_chats ⇒ Boolean
True, if private chats with ordinary users are allowed.
Method Summary
Methods inherited from Base
Instance Attribute Details
#allow_bot_chats ⇒ Boolean
True, if private chats with other bots are allowed.
8 9 10 |
# File 'lib/tdlib/types/target_chat/chosen.rb', line 8 def allow_bot_chats @allow_bot_chats end |
#allow_channel_chats ⇒ Boolean
True, if channel chats are allowed.
8 9 10 |
# File 'lib/tdlib/types/target_chat/chosen.rb', line 8 def allow_channel_chats @allow_channel_chats end |
#allow_group_chats ⇒ Boolean
True, if basic group and supergroup chats are allowed.
8 9 10 |
# File 'lib/tdlib/types/target_chat/chosen.rb', line 8 def allow_group_chats @allow_group_chats end |
#allow_user_chats ⇒ Boolean
True, if private chats with ordinary users are allowed.
8 9 10 |
# File 'lib/tdlib/types/target_chat/chosen.rb', line 8 def allow_user_chats @allow_user_chats end |